package com.ruoyi.project.zjsgfa.mapper;

import java.util.List;
import com.ruoyi.project.zjsgfa.domain.SjZysx;

/**
 * 设计信息-注意事项Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-22
 */
public interface SjZysxMapper 
{
    /**
     * 查询设计信息-注意事项
     * 
     * @param id 设计信息-注意事项主键
     * @return 设计信息-注意事项
     */
    public SjZysx selectSjZysxById(Long id);

    /**
     * 查询设计信息-注意事项列表
     * 
     * @param sjZysx 设计信息-注意事项
     * @return 设计信息-注意事项集合
     */
    public List<SjZysx> selectSjZysxList(SjZysx sjZysx);

    /**
     * 新增设计信息-注意事项
     * 
     * @param sjZysx 设计信息-注意事项
     * @return 结果
     */
    public int insertSjZysx(SjZysx sjZysx);

    /**
     * 修改设计信息-注意事项
     * 
     * @param sjZysx 设计信息-注意事项
     * @return 结果
     */
    public int updateSjZysx(SjZysx sjZysx);

    /**
     * 删除设计信息-注意事项
     * 
     * @param id 设计信息-注意事项主键
     * @return 结果
     */
    public int deleteSjZysxById(Long id);

    /**
     * 批量删除设计信息-注意事项
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSjZysxByIds(Long[] ids);

    int deleteSjZysxByJh(String jh);

    SjZysx selectSjZysxByJh(String jh,String lb);

}
